==> tine20-allinone_2020.03.4.tar.bz2: ActiveSync/js/ActiveSync-lang-en-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0 - ActiveSync\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Default Address book"
: "Default Address book"

, "The default address book to create new contacts in."
: "The default address book to create new contacts in."

, "Default Calendar"
: "Default Calendar"

, "The default calendar to create new events in."
: "The default calendar to create new events in."

, "Default Task List"
: "Default Task List"

, "The default task list to create new tasks in."
: "The default task list to create new tasks in."

, "Sync Devices"
: "Sync Devices"

, "Device ID"
: "Device ID"

, "Devicetype"
: "Devicetype"

, "Owner"
: "Owner"

, "Policy"
: "Policy"

, "ActiveSync Version"
: "ActiveSync Version"

, "User agent"
: "User agent"

, "Model"
: "Model"

, "IMEI"
: "IMEI"

, "Friendly Name"
: "Friendly Name"

, "OS"
: "OS"

, "OS Language"
: "OS Language"

, "Phonenumber"
: "Phonenumber"

, "Sync Device, Sync Devices"
: [
  "Sync Device"
 ,"Sync Devices"

]
, "Device, Devices"
: [
  "Device"
 ,"Devices"

]
, "Devices"
: "Devices"

, "Active Sync"
: "Active Sync"

, "Select a Device"
: "Select a Device"

, "No ActiveSync Device registered"
: "No ActiveSync Device registered"

, "Set as {0} Filter"
: "Set as {0} Filter"

, "Resetted Sync Filter"
: "Resetted Sync Filter"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} filter for device \"{1}\" is now \"{2}\""

, "resetted"
: "resetted"

, "Set Sync Filter"
: "Set Sync Filter"

, "ID"
: "ID"

, "Device Type"
: "Device Type"

, "Operating System"
: "Operating System"

, "Phone Number"
: "Phone Number"

, "Ping Lifetime"
: "Ping Lifetime"

, "Ping Folder"
: "Ping Folder"

, "Remote Wipe"
: "Remote Wipe"

, "Calendar Filter"
: "Calendar Filter"

, "Contacts Filter"
: "Contacts Filter"

, "E-mail Filter"
: "E-mail Filter"

, "Tasks Filter"
: "Tasks Filter"

, "Last Ping"
: "Last Ping"

, "Monitor Last Ping"
: "Monitor Last Ping"

, "Remote Device Reset"
: "Remote Device Reset"

, "Please Confirm"
: "Please Confirm"

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"

, "Quicksearch"
: "Quicksearch"

, "Default Policy"
: "Default Policy"

, "Default Policy installed during setup"
: "Default Policy installed during setup"

, "Default policy for new devices"
: "Default policy for new devices"

, "Enter the id of the policy to apply to newly created devices."
: "Enter the id of the policy to apply to newly created devices."

, "User Agent Deny List"
: "User Agent Deny List"

, "Array of regular expressions of User-Agent strings"
: "Array of regular expressions of User-Agent strings"

, "Disable Access Log"
: "Disable Access Log"

, "Disable ActiveSync Access Log creation."
: "Disable ActiveSync Access Log creation."

, "Filter timeslot for e-mails"
: "Filter timeslot for e-mails"

, "For how long in the past the e-mails should be synchronized."
: "For how long in the past the e-mails should be synchronized."

, "Filter timeslot for events"
: "Filter timeslot for events"

, "For how long in the past the events should be synchronized."
: "For how long in the past the events should be synchronized."

, "Manage ActiveSync devices"
: "Manage ActiveSync devices"

, "See, edit and delete ActiveSync devices"
: "See, edit and delete ActiveSync devices"

, "Reset ActiveSync devices"
: "Reset ActiveSync devices"

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: "Remotely reset ActiveSync devices to factory state, deleting all data"

, "Sync Device"
: "Sync Device"

, "Device"
: "Device"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: ActiveSync/js/ActiveSync-lang-en-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0 - ActiveSync\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: en\nX-Poedit-Country: GB\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Active Sync"
: "Active Sync"

, "Select a Device"
: "Select a Device"

, "No ActiveSync Device registered"
: "No ActiveSync Device registered"

, "Set as {0} Filter"
: "Set as {0} Filter"

, "Resetted Sync Filter"
: "Resetted Sync Filter"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} filter for device \"{1}\" is now \"{2}\""

, "resetted"
: "resetted"

, "Set Sync Filter"
: "Set Sync Filter"

, "Sync Devices"
: "Sync Devices"

, "ID"
: "ID"

, "Device ID"
: "Device ID"

, "Device Type"
: "Device Type"

, "Owner"
: "Owner"

, "Policy"
: "Policy"

, "ActiveSync Version"
: "ActiveSync Version"

, "User agent"
: "User agent"

, "Model"
: "Model"

, "IMEI"
: "IMEI"

, "Friendly Name"
: "Friendly Name"

, "Operating System"
: "Operating System"

, "OS Language"
: "OS Language"

, "Phone Number"
: "Phone Number"

, "Ping Lifetime"
: "Ping Lifetime"

, "Ping Folder"
: "Ping Folder"

, "Remote Wipe"
: "Remote Wipe"

, "Calendar Filter"
: "Calendar Filter"

, "Contacts Filter"
: "Contacts Filter"

, "E-mail Filter"
: "E-mail Filter"

, "Tasks Filter"
: "Tasks Filter"

, "Last Ping"
: "Last Ping"

, "Monitor Last Ping"
: "Monitor Last Ping"

, "Remote Device Reset"
: "Remote Device Reset"

, "Please Confirm"
: "Please Confirm"

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"

, "Quicksearch"
: "Quicksearch"

, "Sync Device, Sync Devices"
: [
  "Sync Device"
 ,"Sync Devices"

]
, "Device, Devices"
: [
  "Device"
 ,"Devices"

]
, "Devices"
: "Devices"

, "Devicetype"
: "Devicetype"

, "OS"
: "OS"

, "Phonenumber"
: "Phonenumber"

, "Default Address book"
: "Default Address book"

, "The default address book to create new contacts in."
: "The default address book to create new contacts in."

, "Default Calendar"
: "Default Calendar"

, "The default calendar to create new events in."
: "The default calendar to create new events in."

, "Default Task List"
: "Default Task List"

, "The default task list to create new tasks in."
: "The default task list to create new tasks in."

, "Default policy for new devices"
: "Default policy for new devices"

, "Enter the id of the policy to apply to newly created devices."
: "Enter the id of the policy to apply to newly created devices."

, "Device Model Agent Deny List"
: "Device Model Agent Deny List"

, "Array of regular expressions of Device-Model strings"
: "Array of regular expressions of Device-Model strings"

, "User Agent Deny List"
: "User Agent Deny List"

, "Array of regular expressions of User-Agent strings"
: "Array of regular expressions of User-Agent strings"

, "Disable Access Log"
: "Disable Access Log"

, "Disable ActiveSync Access Log creation."
: "Disable ActiveSync Access Log creation."

, "Filter timeslot for e-mails"
: "Filter timeslot for e-mails"

, "For how long in the past the e-mails should be synchronized."
: "For how long in the past the e-mails should be synchronized."

, "Filter timeslot for events"
: "Filter timeslot for events"

, "For how long in the past the events should be synchronized."
: "For how long in the past the events should be synchronized."

, "%1$s ActiveSync failure"
: "%1$s ActiveSync failure"

, "Dear user,"
: "Dear user,"

, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
: "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."

, "Thank you."
: "Thank you."

, "Your %1$s Team"
: "Your %1$s Team"

, "Default Policy"
: "Default Policy"

, "Default Policy installed during setup"
: "Default Policy installed during setup"

, "Manage ActiveSync devices"
: "Manage ActiveSync devices"

, "See, edit and delete ActiveSync devices"
: "See, edit and delete ActiveSync devices"

, "Reset ActiveSync devices"
: "Reset ActiveSync devices"

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: "Remotely reset ActiveSync devices to factory state, deleting all data"

, "Sync Device"
: "Sync Device"

, "Device"
: "Device"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
